@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: struct.h,v 1.277.2.4 2005/01/15 23:53:35 amcwilliam Exp $
+ * $Id: struct.h,v 1.277.2.7 2005/07/08 23:29:50 amcwilliam Exp $
  */
 
 #ifndef	__struct_include__
@@ -263,6 +263,7 @@ typedef struct _stats_request StatsRequest;
 #define SERVFLAG_DKEYIN		0x0010	/* Got DKEY PUB I */
 #define SERVFLAG_DKEYOUT	0x0020	/* Got DKEY PUB O */
 #define SERVFLAG_MAPPED		0x0040	/* Already mapped in /MAP */
+#define SERVFLAG_NBURST		0x0080	/* Got Network Burst */
 
 #define UserBurst(x)		((x)->serv->flags & SERVFLAG_USERBURST)
 #define TopicBurst(x)		((x)->serv->flags & SERVFLAG_TOPICBURST)
@@ -272,6 +273,7 @@ typedef struct _stats_request StatsRequest;
 #define GotDKEYin(x)		((x)->serv->flags & SERVFLAG_DKEYIN)
 #define GotDKEYout(x)		((x)->serv->flags & SERVFLAG_DKEYOUT)
 #define IsMapped(x)		((x)->serv->flags & SERVFLAG_MAPPED)
+#define GotNBurst(x)		((x)->serv->flags & SERVFLAG_NBURST)
 
 #define SetUserBurst(x)		((x)->serv->flags |= SERVFLAG_USERBURST)
 #define SetTopicBurst(x)	((x)->serv->flags |= SERVFLAG_TOPICBURST)
@@ -280,6 +282,7 @@ typedef struct _stats_request StatsRequest;
 #define SetDKEYin(x)		((x)->serv->flags |= SERVFLAG_DKEYIN)
 #define SetDKEYout(x)		((x)->serv->flags |= SERVFLAG_DKEYOUT)
 #define SetMapped(x)		((x)->serv->flags |= SERVFLAG_MAPPED)
+#define SetGotNBurst(x)		((x)->serv->flags |= SERVFLAG_NBURST)
 
 #define ClearUserBurst(x)	((x)->serv->flags &= ~SERVFLAG_USERBURST)
 #define ClearTopicBurst(x)	((x)->serv->flags &= ~SERVFLAG_TOPICBURST)
@@ -288,6 +291,7 @@ typedef struct _stats_request StatsRequest;
 #define ClearDKEYin(x)		((x)->serv->flags &= ~SERVFLAG_DKEYIN)
 #define ClearDKEYout(x)		((x)->serv->flags &= ~SERVFLAG_DKEYOUT)
 #define ClearMapped(x)		((x)->serv->flags &= ~SERVFLAG_MAPPED)
+#define ClearGotNBurst(x)	((x)->serv->flags &= ~SERVFLAG_NBURST)
 
 /* SERVER capabilities */
 #define CAP_TS			0x00000001	/* Supports TS protocol */
@@ -303,13 +307,15 @@ typedef struct _stats_request StatsRequest;
 #define CAP_TOK1		0x00000400	/* Supports TOK1 protocol */
 #define CAP_NOQUIT		0x00000800	/* Supports NOQUIT protocol */
 #define CAP_TSMODE		0x00001000	/* Supports TS in MODE */
+#define CAP_NBURST		0x00002000	/* Supports NBURST */
 
-#define DEFAULT_CAPABS		(CAP_BURST|CAP_UNCONN|CAP_ZIP|CAP_SSJ3|CAP_SN2|CAP_VHOST|CAP_SUID|CAP_TOK1|CAP_TSMODE)
+#define DEFAULT_CAPABS		(CAP_BURST|CAP_UNCONN|CAP_ZIP|CAP_SSJ3|CAP_SN2|\
+				CAP_VHOST|CAP_SUID|CAP_TOK1|CAP_TSMODE|CAP_NBURST|\
+				CAP_NOQUIT)
 #define ID_CAPS			(CAP_SUID|CAP_TOK1)
 #define NO_CAPS			0
 
 #define CapTS(x)		((x)->localClient->capabs & CAP_TS)
-#define CapNOQUIT(x)		((x)->localClient->capabs & CAP_NOQUIT)
 #define CapBURST(x)		((x)->localClient->capabs & CAP_BURST)
 #define CapUNCONNECT(x)		((x)->localClient->capabs & CAP_UNCONN)
 #define CapZIP(x)		((x)->localClient->capabs & CAP_ZIP)
@@ -322,6 +328,7 @@ typedef struct _stats_request StatsRequest;
 #define CapID(x)		(((x)->localClient->capabs & ID_CAPS) == ID_CAPS)
 #define CapNOQUIT(x)		((x)->localClient->capabs & CAP_NOQUIT)
 #define CapTSMODE(x)		((x)->localClient->capabs & CAP_TSMODE)
+#define CapNBURST(x)		((x)->localClient->capabs & CAP_NBURST)
 
 #define HasMode(x, y)		((x)->umode & (y))
 #define AddMode(x, y)		((x)->umode |= (y))
@@ -600,8 +607,10 @@ struct Server {
 	void *rc4_in;			/* etc */
 	void *rc4_out;			/* etc */
 #endif
+#ifdef USE_ZLIB
 	void *zip_out;			/* inbound zipped data */
 	void *zip_in;			/* outbound zipped data */
+#endif
 	ConfigItem_link *conf;		/* config */
 	unsigned short flags;		/* Server-only flags */
 	aClient *userid[ID_MAP_SIZE];
@@ -848,7 +857,11 @@ struct _stats_request {
 #define use_msg(x,t)	((CapID(t) && ((x)->tok_str != NULL)) ? (x)->tok_str : (x)->msg_str)
 
 /* Zipped session has data waiting */
+#ifdef USE_ZLIB
 #define zip_out(x)	(OutputZIP(x) && ((ziplink_out *)(x)->serv->zip_out)->size)
+#else
+#define zip_out(x)	(0)
+#endif
 
 /* return values for hunt_server() */
 
