@@ -5,13 +5,17 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: zlink.h,v 1.8.2.1 2004/12/07 03:04:54 pneumatus Exp $
+ * $Id: zlink.h,v 1.8.2.3 2005/05/06 22:57:42 amcwilliam Exp $
  */
 
 #ifndef __zlink_h__
 #define __zlink_h__
 
-#include "zlib.h"
+#include "setup.h"
+
+#ifdef USE_ZLIB
+
+#include <zlib.h>
 
 #define ZIP_MIN_BLOCK		1024
 #define ZIP_MAX_BLOCK		8192
@@ -42,4 +46,6 @@ extern char *zip_output(void *, char *, int *, int, int *);
 extern void zip_out_get_stats(void *, unsigned long *, unsigned long *, double *);
 extern void zip_destroy_output_session(void *);
 
+#endif /* USE_ZLIB */
+
 #endif /* __zlink_h__ */
