@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: m_stats.c,v 1.106.2.3 2005/03/14 00:49:44 amcwilliam Exp $
+ * $Id: m_stats.c,v 1.106.2.4 2005/05/06 22:57:41 amcwilliam Exp $
  */
 
 #include "config.h"
@@ -37,7 +37,7 @@ Hook *h_stats = NULL;
 Module MOD_HEADER(m_stats) = {
 	"m_stats",
 	"/STATS command",
-	6, "$Revision: 1.106.2.3 $"
+	6, "$Revision: 1.106.2.4 $"
 };
 
 int MOD_LOAD(m_stats)()
@@ -176,6 +176,7 @@ static void stats_bandwidth(aClient *sptr, char *unused)
 			send_me_debugNA(sptr, ":B  - RC4 Encrypted");
 		}
 
+#ifdef USE_ZLIB
 		if (InputZIP(acptr)) {
 			unsigned long in_b, out_b;
 			double ratio;
@@ -198,6 +199,7 @@ static void stats_bandwidth(aClient *sptr, char *unused)
 					_GMKS(out_b / 1024.0), ratio);
 			}
 		}
+#endif /* USE_ZLIB */
 	}
 
 	send_me_debug(sptr, "B :%d total servers", i);
