@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: engine.c,v 1.53.2.2 2004/12/07 03:05:09 pneumatus Exp $
+ * $Id: engine.c,v 1.53.2.4 2005/05/06 23:33:28 amcwilliam Exp $
  */
 
 #include "setup.h"
@@ -307,6 +307,7 @@ void engine_send_queued(aClient *cptr)
 		return;
 	}
 
+#ifdef USE_ZLIB
 	if (zip_out(cptr)) {
 		if (SBufLength(&cptr->localClient->sendQ)) {
 			more = 1;
@@ -333,6 +334,7 @@ void engine_send_queued(aClient *cptr)
 			}
 		}
 	}
+#endif /* USE_ZLIB */
 
 	while (SBufLength(&cptr->localClient->sendQ)) {
 		buf = sbuf_map(&cptr->localClient->sendQ, &len);
@@ -373,10 +375,14 @@ void engine_send_queued(aClient *cptr)
 		}
 
 		if (more && !SBufLength(&cptr->localClient->sendQ)) {
+#ifdef USE_ZLIB
 			int ldata = SendingBurst(cptr);
+#endif
+
 
 			more = 0;
 
+#ifdef USE_ZLIB
 			buf = zip_output(cptr->serv->zip_out, NULL, &len, 1, &ldata);
 			if (len == -1) {
 				sendto_realops("Zip output error (more) for %s: (%d) %s",
@@ -384,6 +390,7 @@ void engine_send_queued(aClient *cptr)
 				engine_write_error(cptr, "Zip output error (more) for %s", IRCERR_ZIP);
 				return;
 			}
+#endif
 
 #ifdef USE_OPENSSL
 			if (OutputRC4(cptr)) {
