@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: ircd.c,v 1.239.2.5 2005/02/21 02:32:46 amcwilliam Exp $
+ * $Id: ircd.c,v 1.239.2.14 2005/07/27 19:34:28 amcwilliam Exp $
  */
 
 #include "struct.h"
@@ -30,6 +30,7 @@
 #include "xmode.h"
 #include "modules.h"
 #include "user_ban.h"
+#include "zlink.h"
 #include <sys/file.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -98,9 +99,6 @@ char server_options[] = {
 #ifdef USE_OPENSSL
 	'E',
 #endif
-#ifdef USE_BLALLOC
-	'B',
-#endif
 #ifdef USE_THROTTLE
 	'T',
 #endif
@@ -142,6 +140,9 @@ char server_options[] = {
 #endif
 #ifdef USE_ASSERT
 	'a',
+#endif
+#ifdef USE_ZLIB
+	'Z',
 #endif
 	'\0'
 };
@@ -553,7 +554,7 @@ static void init_hash_tables()
 	clear_scache_hash_table();
 }
 
-static void init_maximumfds()
+static void init_maximum_fds()
 {
 #ifdef RLIMIT_FD_MAX
 	struct rlimit limit;
@@ -731,15 +732,18 @@ int main(int argc, char *argv[])
 	}
 #endif
 
+	/* We chdir to the configuration directory early on */
+	if (chdir(CONF_DIR) == -1) {
+		fprintf(stderr, "ERROR: cannot change to conf directory: %s\n"
+						"       CONF_DIR: %s", strerror(errno), CONF_DIR);
+		exit(EXIT_FAILURE);
+	}
+
 	set_time();
 	init_hash_tables();
-#ifdef USE_BLALLOC
 	init_blockheap(0);
-#endif
 	dlink_init();
-#ifdef USE_BLALLOC
 	init_blockheap(1);
-#endif
 	init_ip_hash();
 	init_userban();
 	hook_init();
@@ -795,7 +799,7 @@ int main(int argc, char *argv[])
 	fprintf(stderr, "rageircd: initialisation complete, attempting to boot."LF);
 
 	set_time();
-	init_maximumfds();
+	init_maximum_fds();
 	build_isupport();
 
 	strncpyzt(me.name, ServerInfo->name, sizeof(me.name));
@@ -834,13 +838,27 @@ int main(int argc, char *argv[])
 
 	write_pidfile();
 	open_listeners();
+	init_masking_keys(); /* Masking keys cannot be rehashed. */
 
+	/* Setup some basic events */
 	add_event("calculate_bandwidth", calculate_bandwidth, NULL, 2, 1);
-
-	ircd_running = 1;
-	Debug((DEBUG_NOTICE, "Server ready..."));
-
+	
 	set_time();
+	
+	/* And we're ready... */
+	ircd_running = 1;
+
+#ifdef USE_ZLIB
+	Debug((DEBUG_DEBUG, "Server using zlib %s", zlibVersion()));
+#endif
+#ifdef USE_OPENSSL
+	Debug((DEBUG_DEBUG, "Server using %s", OPENSSL_VERSION_TEXT));
+#endif
+	Debug((DEBUG_DEBUG, "Server ready, version: %s revision: %s compile: %s)",
+		ircd_version, revision, compile_number));
+	
+	/* Try connecting to something, then begin I/O */
+	try_connections(&me);
 	io_loop();
 
 	return 0;
