@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: s_conf2.c,v 1.287.2.13 2005/02/26 17:47:48 amcwilliam Exp $
+ * $Id: s_conf2.c,v 1.287.2.15 2005/07/09 00:39:20 amcwilliam Exp $
  */
 
 #include "struct.h"
@@ -852,9 +852,11 @@ void *parse_link(ConfigEntry *entry)
 		else if (!mycmp(e->varname, "auto_connect")) {
 			linkp->flags |= get_option(e->vardata, LINK_AUTOCONNECT);
 		}
+#ifdef USE_ZLIB
 		else if (!mycmp(e->varname, "compressed")) {
 			linkp->flags |= get_option(e->vardata, LINK_COMPRESS);
 		}
+#endif
 #ifdef USE_OPENSSL
 		else if (!mycmp(e->varname, "encrypted")) {
 			linkp->flags |= get_option(e->vardata, LINK_SECURE);
@@ -1785,12 +1787,20 @@ void conf_rehash()
 
 	init_conf();
 
+	/* Reinitialise my own socket stuffs. */
 	close_listeners();
 	restart_resolver();
 	open_listeners();
 
+	/* Rebuild the isupport list. */
 	build_isupport();
+	
+	/* Re-read any message files. */
 	rehash_message_files();
+	
+	/* And reset the autoconnect event */
+	del_event_byfunc(try_connections, NULL);
+	try_connections(&me);
 
 	Internal.rehashing = 0;
 }
