@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: s_misc.c,v 1.128.2.1 2004/12/07 03:05:36 pneumatus Exp $
+ * $Id: s_misc.c,v 1.128.2.2 2005/06/26 18:47:07 amcwilliam Exp $
  */
 
 #include "struct.h"
@@ -51,7 +51,7 @@ static char *weekdays[] = {
 	"Saturday"
 };
 
-static void exit_one_client(aClient *, aClient *, aClient *, char *);
+static void exit_one_client(aClient *, aClient *, aClient *, char *, int);
 
 struct stats ircst, *ircstp = &ircst;
 
@@ -380,6 +380,8 @@ int exit_client_zap(aClient *cptr, aClient *sptr, userBan *uban)
 
 int exit_client(aClient *cptr, aClient *sptr, aClient *from, char *comment)
 {
+	int is_remote = 1;
+	
 	if (MyConnect(sptr)) {
 		HookData hdata = HOOKDATA_INIT;
 		hdata.sptr = sptr;
@@ -391,6 +393,8 @@ int exit_client(aClient *cptr, aClient *sptr, aClient *from, char *comment)
 			return 0;
 		}
 		SetClosing(sptr);
+		
+		is_remote = 0;
 
 		if (sptr->localClient->auth != NULL) {
 			connauth_delete_queries(sptr);
@@ -481,18 +485,14 @@ int exit_client(aClient *cptr, aClient *sptr, aClient *from, char *comment)
 			}
 		}
 	}
-	else if (IsPerson(sptr) && !IsULine(sptr) && !Internal.net_split) {
-		sendto_realops_lev(GCCONN_LEV, "Client exiting at %s: %s (%s@%s) [%s]", sptr->user->server,
-			sptr->name, sptr->username, sptr->host,
-			NormalExit(sptr) ? !GeneralConfig.show_cliconn_quit_msgs ? "Client Quit" : comment : comment);
-	}
 
-	exit_one_client(cptr, sptr, from, comment);
+	exit_one_client(cptr, sptr, from, comment, is_remote);
 
 	return (cptr == sptr) ? FLUSH_BUFFER : 0;
 }
 
-static void exit_one_client(aClient *cptr, aClient *sptr, aClient *from, char *comment)
+static void exit_one_client(aClient *cptr, aClient *sptr, aClient *from,
+  char *comment, int is_remote)
 {
 	chanMember *cm;
 	SLink *lp;
@@ -519,6 +519,16 @@ static void exit_one_client(aClient *cptr, aClient *sptr, aClient *from, char *c
 			sendto_serv_msg_butone(cptr, sptr, &CMD_QUIT, ":%s", comment);
 		}
 		if (sptr->user != NULL) {
+			/* Send global client connect notice here rather than in
+			 * exit_client() so we know this is not a netsplit.
+			 */
+			if (!IsULine(sptr) && is_remote) {
+				sendto_realops_lev(GCCONN_LEV, "Client exiting at %s: "
+					"%s (%s@%s) [%s]", sptr->user->server, sptr->name,
+					sptr->username, sptr->host,
+					(NormalExit(sptr) && !GeneralConfig.show_cliconn_quit_msgs) ? "Client Quit" : comment);
+			}
+			
 			send_part_to_common_channels(sptr, comment);
 			send_quit_to_common_channels(sptr, comment);
 
