@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: s_user.c,v 1.220.2.1 2004/12/07 03:05:39 pneumatus Exp $
+ * $Id: s_user.c,v 1.220.2.2 2005/06/26 18:47:07 amcwilliam Exp $
  */
 
 #include "struct.h"
@@ -531,7 +531,10 @@ int register_user(aClient *cptr, aClient *sptr, char *nick, char *username)
 			return exit_client(sptr, sptr, &me, "USER server wrong direction");
 		}
 		
-		if (!IsULine(sptr) && !SendingBurst(cptr)) {
+		/* Clients on pre-2.0.1 servers will not be announced via gcliconn,
+		 * however if we get here then !CapSNICK(cptr) is TRUE! :-(
+		 */
+		if (GotNBurst(cptr) && !IsULine(sptr)) {
 			sendto_realops_lev(GCCONN_LEV, "Client connecting at %s: %s (%s@%s)",
 				sptr->user->server, sptr->name, sptr->username, sptr->host);
 		}
