@@ -5,7 +5,7 @@
  * This software is free, licensed under the General Public License.
  * Please refer to doc/LICENSE and doc/README for further details.
  *
- * $Id: send.c,v 1.153.2.3 2004/12/13 23:33:06 amcwilliam Exp $
+ * $Id: send.c,v 1.153.2.4 2005/05/06 22:57:40 amcwilliam Exp $
  */
 
 #include "struct.h"
@@ -44,6 +44,7 @@ void send_queued_buffers()
 	dlink_node *node;
 
 	/* Send any queued data if it's not blocked */
+	/* zip_out() will be 0 if !USE_ZLIB */
 
 	DLINK_FOREACH_PREV_DATA(lserver_list.tail, node, cptr, aClient) {
 		if ((SBufLength(&cptr->localClient->sendQ) || zip_out(cptr)) && !IsBlocked(cptr)) {
@@ -139,6 +140,7 @@ static void send_message(aClient *to, char *buf, int len, void *shared_buf)
 		to->localClient->listener->sendM++;
 	}
 
+#ifdef USE_ZLIB
 	if (OutputZIP(to)) {
 		int ldata = SendingBurst(to);
 
@@ -152,6 +154,7 @@ static void send_message(aClient *to, char *buf, int len, void *shared_buf)
 			return;
 		}
 	}
+#endif
 
 #ifdef USE_OPENSSL
 	if (OutputRC4(to)) {
